@@ -1084,6 +1084,9 @@ gdm_peek_local_address_list (void)
 		return g_list_append (the_list, sin6);
 	}
 
+	memset (&hints, 0, sizeof (hints));
+	hints.ai_family = AF_INET;
+
 	if (getaddrinfo (hostbuf, NULL, &hints, &result) != 0) {
 		gdm_debug ("%s: Could not get address from hostname!", "gdm_peek_local_address_list");
 
